#!/bin/sh

# PTF AE Install

echo "WebSphere Application Server 4.0, Advanced Edition Single Server PTF 2"
echo "Please shut down the Application Server and any Webservers that might be running."
echo "If not the PTF may not be installed properly"
echo "If you want to install silently, please issue install.sh -silent"

SILENT_INSTALL="false"

OS_NAME=`uname`

if [ -z "$IHS_INSTALL" ]
    then IHS_INSTALL="true"
fi

JDK_INSTALL="false"
J2C_INSTALL="maybe"

# Set variables based on OS name
case "${OS_NAME}" in
  AIX)
   IHS_DIR="/usr/HTTPServer"
   JDK_INSTALL="true"
   ;;
  SunOS|Solaris)
   IHS_DIR="/opt/IBMHTTPD"
   JDK_INSTALL="true"
   ;;
  HP-UX)
   IHS_DIR="/opt/HTTPServer"
   JDK_INSTALL="true"
   ;;
  Linux)
   IHS_DIR="/opt/IBMHTTPServer"
   JDK_INSTALL="true"
   LD_ASSUME_KERNEL=2.2.5
   export LD_ASSUME_KERNEL
   ;;
  *)
   echo "Unspported platform: $OS_NAME"
   echo "Exiting ..."
   exit 1
   ;;
esac

echo "silent install        = " $SILENT
echo "IHS install           = " $IHS_INSTALL
echo "J2C Connector install = " $J2C_INSTALL

if [ "$OS_NAME" = "AIX" ] ; then
  slibclean
fi

# Check for silent install
if [ "$1" = "-silent" ] ; then
   if [ "$WAS_DIR" = "" ] ; then
      echo ""
      echo "Please set all of the following environment variables."
      echo "WAS_DIR : Set it to the WebSphere root directory ( eg: /usr/WebSphere/AppServer )"
      echo "IHS_INSTALL : Set it to true if you want to install IHS PTF, else false"
      exit 1
   else
      SILENT_INSTALL="true"
   fi
fi

if [ "$SILENT_INSTALL" = "true" ] ; then
   echo "Installing PTF silently"
   J2C_INSTALL="true"
fi


DELTA_JAR="was40_aes_ptf_2.jar"
DELTA_LOG="was40_aes_ptf_2.log"
IHS_PTF="ihs_ptf_2.jar"
IHS_BACKUP_JAR="ihs_ptf_2_backup.jar"
IHS_LOG_FILE="ihs_ptf_2.log"
##
JAVA_PTF="jdk_ptf_2.jar"
BACKUP_JAR="was40_ptf_2_backup.jar"
JAVA_BACKUP_JAR="jdk_ptf_2_backup.jar"
UINSTALL_FILE="uninstall_ptf_2.sh"
LOG_FILE="was40_ptf_2.log"
JAVA_LOG_FILE="jdk_ptf_2.log"

##  echo "OS_NAME      = $OS_NAME"
##  echo "DELTA_JAR    = $DELTA_JAR"
##  echo "DELTA_LOG    = $DELTA_LOG"
##  echo "IHS_PTF      = $IHS_PTF"
##  echo "JAVA_PTF     = $JAVA_PTF"
##  echo "IHS_DIR      = $IHS_DIR"

if [ "$SILENT_INSTALL" = "false" ] ; then
   while :
   do
    echo "Please enter the WebSphere root directory"
    read WAS_DIR
    if [ "${WAS_DIR}" = "" ] ; then
       continue
    fi

    if [ ! -d ${WAS_DIR} ] ; then
            echo
            echo "Unable to locate file: ${WAS_DIR}/properties/com/ibm/websphere/product.xml"
            echo
            continue
#    elif [ ! -f ${WAS_DIR}/properties/com/ibm/websphere/product.xml ] ; then
#            echo
#            echo "Unable to locate file: ${WAS_DIR}/properties/com/ibm/websphere/product.xml"
#            echo
#            continue
    fi
    break
   done
fi

#Set the JAVA_HOME and PATH
if [ -d $WAS_DIR/java ] ; then
  JAVA_HOME=$WAS_DIR/java
  export JAVA_HOME
else
  JAVA_HOME=$WAS_DIR/jre
  export JAVA_HOME
fi


case "${OS_NAME}" in
  AIX)
    PATH=$JAVA_HOME/jre/bin:$JAVA_HOME/bin:$PATH
    export PATH
    ;;
  SunOS|Solaris)
    PATH=$JAVA_HOME/jre/bin:$PATH
    export PATH
    ;;
  HP-UX)
    PATH=$JAVA_HOME/jre/bin:/usr/sbin:$PATH
    export PATH
    ;;
  Linux)
    PATH=$JAVA_HOME/jre/bin:$PATH
    export PATH
    ;;
esac


#Installing the WAS PTF
echo "Installing the WebSphere Application Server 4.0 PTF 2"

java -jar $DELTA_JAR -TargetDir $WAS_DIR -backupJar $WAS_DIR/$BACKUP_JAR -log $WAS_DIR/logs/$LOG_FILE

if [ $? -ne 0 ] ; then
   echo "Either the user has chosen to exit, or there was an error "
   echo "during the WebSphere PTF upgrade."
   echo "In case of error, run $UINSTALL_FILE to back out the changes."
   exit
fi


#Installing the JDK PTF
if [ "$JDK_INSTALL" = "true" ] ; then
  echo "Installing JDK PTF 2"
  JAVA_PTF_DIR=$WAS_DIR/java_ptf_2
  mkdir $JAVA_PTF_DIR

  if [ "$OS_NAME" = "Linux" ]  ; then
     cp -Rfd $JAVA_HOME/* $JAVA_PTF_DIR/
  else
     cp -R $JAVA_HOME/* $JAVA_PTF_DIR/
  fi

  java -jar $JAVA_PTF -TargetDir $JAVA_PTF_DIR -backupJar $WAS_DIR/$JAVA_BACKUP_JAR -log $WAS_DIR/logs/$JAVA_LOG_FILE -SkipVer

  if [ $? -ne 0 ] ; then
      echo "Either the user has chosen to exit, or there was an error "
      echo "during the JDK PTF upgrade."
      echo "In case of error, run $UINSTALL_FILE to back out the changes."
      exit
  fi

  sleep 5

  # Remove the old code from the Java home.
  rm -rf $JAVA_HOME/*

  # Make sure to retain symlinks on Linux.
  if [ "$OS_NAME" = "Linux" ]  ; then
     cp -Rfd $JAVA_PTF_DIR/* $JAVA_HOME/

  else
     cp -R $JAVA_PTF_DIR/* $JAVA_HOME/
  fi

  # Done patching.  Remove ptf patch dir.
  rm -rf $JAVA_PTF_DIR

  case "${OS_NAME}" in
    HP-UX)
     chmod -R 755 $JAVA_HOME/jre/lib/PA_RISC/*
     chmod -R 755 $JAVA_HOME/jre/lib/PA_RISC2.0/*
     chmod 755 $JAVA_HOME/jre/bin/.start_xfs
     chmod 755 $JAVA_HOME/bin/.start_xfs
     chmod 755 $JAVA_HOME/bin/PA_RISC/native_threads/.start_xfs
     chmod 755 $JAVA_HOME/bin/PA_RISC2.0/native_threads/.start_xfs
     chmod 755 $JAVA_HOME/jre/bin/PA_RISC/native_threads/.start_xfs
     chmod 755 $JAVA_HOME/jre/bin/PA_RISC2.0/native_threads/.start_xfs
     ;;
    SunOS|Solaris)
     chmod -R 755 $JAVA_HOME/jre/lib/sparc/*
     ;;
    *)
     ;;
  esac
fi

#Installing the IHS PTF
if [ "$SILENT_INSTALL" = "false" ] ; then
  if [ "$IHS_INSTALL" = "true" ] ; then
    while :
    do
      echo "WARNING: If you install the IBM HTTP Server PTF, the back level of IHS may not work properly with the new level of GSkit."
      echo "Please enter whether you want to install IHS WebServer PTF (y/n)"
      read IHS_INSTALL
      if [ "${IHS_INSTALL}" = "" ] ; then
         continue
      fi

      case "${IHS_INSTALL}" in
            y|Y)
              IHS_INSTALL="true"
              break
              ;;
            n|N)
              IHS_INSTALL="false"
              break
              ;;
            *)
              echo ""
              echo "Please enter y for Yes or n for No"
              echo ""
              continue
              ;;
      esac
    done
  fi
fi


case "${IHS_INSTALL}" in
 true)
   echo "Installing IHS PTF"
   java -jar $IHS_PTF -TargetDir $IHS_DIR -backupJar $WAS_DIR/$IHS_BACKUP_JAR -log $WAS_DIR/logs/$IHS_LOG_FILE -SkipVer

   if [ $? -ne 0 ] ; then
      echo "Either the user has chosen to exit, or there was an error "
      echo "during the IBM HTTP Server PTF upgrade."
      echo "In case of error, run $UINSTALL_FILE to back out the changes."
      exit
   fi

   echo "Installing the gskit package"
   case "${OS_NAME}" in
     AIX)
        echo "Installing new version of GSkit."
        installp -acgXd $IHS_DIR all
        ;;
     SunOS|Solaris)
        echo "Installing new version of GSkit."
        pkgadd -a admin -d $IHS_DIR all
        ;;
     HP-UX)
        echo "Uninstalling previous version of GSkit."
        /usr/sbin/swremove -x autoselect_dependents=false -x enforce_dependencies=false gsk5bas
        echo "Installing new version of GSkit."
        /usr/bin/chmod u+x $IHS_DIR/gsk5bas/catalog/gsk5bas/gsk5bas/postinstall
        /usr/bin/chmod u+x $IHS_DIR/gsk5bas/catalog/gsk5bas/gsk5bas/preremove
        /usr/sbin/swreg -l depot $IHS_DIR/gsk5bas/gsk5bas
        /usr/sbin/swinstall -s $IHS_DIR/gsk5bas gsk5bas
        ;;
     Linux)
        echo "Upgrading GSkit"
        rpm --nodeps -ev gsk5bas-5.0-3.61
        rpm -Uvh $IHS_DIR/gsk5bas*.rpm
        ;;
   esac
   ;;
 *)
   case "${OS_NAME}" in
     SunOS|Solaris)
	#if IHS is not upgraded and OS is SUN then install GSKIT4
	# extract GSKIT4 from IHS PTF
	jar -xvf $IHS_PTF /gsk4bas
	# install package
        pkgadd -a admin -d / gsk4bas
	rm -fR /gsk4bas
        ;;
     *)
        ;;
   esac
esac

if [ "$OS_NAME" = "AIX" ] ; then
  slibclean
fi

#End install
